"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeFolder = void 0;
const vscode = require("vscode");
const path = require("path");
const fs = require("fs");
async function initializeFolder() {
    const options = {
        canSelectFiles: false,
        canSelectFolders: true,
        canSelectMany: false,
        openLabel: '选择酒馆文件夹'
    };
    try {
        const folderUri = await vscode.window.showOpenDialog(options);
        if (folderUri && folderUri[0]) {
            const folderPath = folderUri[0].fsPath;
            const iconPath = path.join(folderPath, 'public', 'st.ico');
            const worldsPath = path.join(folderPath, 'data', 'default-user', 'worlds');
            if (!fs.existsSync(iconPath)) {
                vscode.window.showErrorMessage('请选择酒馆根目录（需包含 /public/st.ico）');
                return await initializeFolder();
            }
            if (!fs.existsSync(worldsPath)) {
                fs.mkdirSync(worldsPath, { recursive: true });
            }
            await vscode.workspace.getConfiguration().update('tavernPacker.rootPath', folderPath, true);
            vscode.window.showInformationMessage('酒馆文件夹初始化成功！');
        }
    }
    catch (error) {
        const errorMessage = error instanceof Error ? error.message : '未知错误';
        vscode.window.showErrorMessage('初始化失败：' + errorMessage);
    }
}
exports.initializeFolder = initializeFolder;
//# sourceMappingURL=init.js.map