"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllFiles = exports.isValidFile = exports.createFileEntry = void 0;
const path = require("path");
const fs = require("fs");
function createFileEntry(filePath) {
    const stat = fs.statSync(filePath);
    const name = path.basename(filePath);
    return {
        path: filePath,
        name,
        nameWithoutExt: path.basename(filePath, path.extname(filePath)),
        extension: path.extname(filePath).toLowerCase(),
        isDirectory: stat.isDirectory(),
        dirPath: path.dirname(filePath)
    };
}
exports.createFileEntry = createFileEntry;
function isValidFile(entry) {
    const validExtensions = ['.md', '.json', '.yml', '.yaml'];
    return !entry.isDirectory &&
        validExtensions.includes(entry.extension) &&
        !entry.name.startsWith('!') &&
        entry.name !== 'CONFIG.json' &&
        entry.name !== 'output.json';
}
exports.isValidFile = isValidFile;
async function getAllFiles(dir) {
    const entries = fs.readdirSync(dir, { withFileTypes: true });
    const files = [];
    for (const entry of entries) {
        const fullPath = path.join(dir, entry.name);
        const fileEntry = createFileEntry(fullPath);
        if (fileEntry.isDirectory) {
            files.push(fileEntry);
            files.push(...await getAllFiles(fullPath));
        }
        else {
            files.push(fileEntry);
        }
    }
    return files.sort((a, b) => {
        if (a.isDirectory && !b.isDirectory)
            return -1;
        if (!a.isDirectory && b.isDirectory)
            return 1;
        return a.path.localeCompare(b.path);
    });
}
exports.getAllFiles = getAllFiles;
//# sourceMappingURL=fileSystem.js.map